==> unit-1.0.44-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractNodeLinksInTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractNodeLinksInTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public LinksInTable linksInTable;
	public NodeLinksInTemplate.LinksInTable. LinksInTableLabelHeading linksInTableLabelHeading;
	public NodeLinksInTemplate.LinksInTable.LinksInTableLabelHeading. _12_38_11182118849 _12_38_11182118849;
	public NodeLinksInTemplate.LinksInTable. LinksInTableDescriptionHeading linksInTableDescriptionHeading;
	public NodeLinksInTemplate.LinksInTable.LinksInTableDescriptionHeading. _15_44_11718484075 _15_44_11718484075;

    public AbstractNodeLinksInTemplate(B box) {
        super(box);
        id("nodeLinksInTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (linksInTable == null) linksInTable = register(new LinksInTable(box()).<LinksInTable>id("a_1124382024").owner(AbstractNodeLinksInTemplate.this));
		if (linksInTable != null) linksInTableLabelHeading = linksInTable.linksInTableLabelHeading;
		if (linksInTableLabelHeading != null) _12_38_11182118849 = linksInTable.linksInTableLabelHeading._12_38_11182118849;
		if (linksInTable != null) linksInTableDescriptionHeading = linksInTable.linksInTableDescriptionHeading;
		if (linksInTableDescriptionHeading != null) _15_44_11718484075 = linksInTable.linksInTableDescriptionHeading._15_44_11718484075;
	}

	public class LinksInTable extends io.intino.alexandria.ui.displays.components.Table<B, io.intino.alexandria.ui.displays.components.Row, org.monet.space.kernel.model.Node>  {
		public NodeLinksInTemplate.LinksInTable. LinksInTableLabelHeading linksInTableLabelHeading;
		public NodeLinksInTemplate.LinksInTable. LinksInTableDescriptionHeading linksInTableDescriptionHeading;

		public LinksInTable(B box) {
			super(box);

			_pageSize(20);
		}

		@Override
		public void init() {
			super.init();
			if (linksInTableLabelHeading == null) linksInTableLabelHeading = register(new LinksInTableLabelHeading(box()).<LinksInTableLabelHeading>id("a_1289219689").owner(AbstractNodeLinksInTemplate.this));
			if (linksInTableDescriptionHeading == null) linksInTableDescriptionHeading = register(new LinksInTableDescriptionHeading(box()).<LinksInTableDescriptionHeading>id("a1141824812").owner(AbstractNodeLinksInTemplate.this));
		}


		public LinksInTableRow create(org.monet.space.kernel.model.Node item) {
			LinksInTableRow row = new LinksInTableRow((UnitBox)box());
			row.id(java.util.UUID.randomUUID().toString());
			row.item(item);
			return row;
		}
		public class LinksInTableLabelHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public NodeLinksInTemplate.LinksInTable.LinksInTableLabelHeading. _12_38_11182118849 _12_38_11182118849;

			public LinksInTableLabelHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_12_38_11182118849 == null) _12_38_11182118849 = register(new _12_38_11182118849(box()).<_12_38_11182118849>id("a1974135901").owner(AbstractNodeLinksInTemplate.this));
			}

			public class _12_38_11182118849 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _12_38_11182118849(B box) {
					super(box);
					_value("Título");
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}

		public class LinksInTableDescriptionHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public NodeLinksInTemplate.LinksInTable.LinksInTableDescriptionHeading. _15_44_11718484075 _15_44_11718484075;

			public LinksInTableDescriptionHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_15_44_11718484075 == null) _15_44_11718484075 = register(new _15_44_11718484075(box()).<_15_44_11718484075>id("a1460818572").owner(AbstractNodeLinksInTemplate.this));
			}

			public class _15_44_11718484075 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _15_44_11718484075(B box) {
					super(box);
					_value("Descripción");
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}
	}
}

==> unit-1.1.25-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractNodeLinksInTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractNodeLinksInTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public LinksInTable linksInTable;
	public NodeLinksInTemplate.LinksInTable. LinksInTableLabelHeading linksInTableLabelHeading;
	public NodeLinksInTemplate.LinksInTable.LinksInTableLabelHeading. _12_38_11182118849 _12_38_11182118849;
	public NodeLinksInTemplate.LinksInTable. LinksInTableDescriptionHeading linksInTableDescriptionHeading;
	public NodeLinksInTemplate.LinksInTable.LinksInTableDescriptionHeading. _15_44_11718484075 _15_44_11718484075;

    public AbstractNodeLinksInTemplate(B box) {
        super(box);
        id("nodeLinksInTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (linksInTable == null) linksInTable = register(new LinksInTable(box()).<LinksInTable>id("a_1124382024").owner(AbstractNodeLinksInTemplate.this));
		if (linksInTable != null) linksInTableLabelHeading = linksInTable.linksInTableLabelHeading;
		if (linksInTableLabelHeading != null) _12_38_11182118849 = linksInTable.linksInTableLabelHeading._12_38_11182118849;
		if (linksInTable != null) linksInTableDescriptionHeading = linksInTable.linksInTableDescriptionHeading;
		if (linksInTableDescriptionHeading != null) _15_44_11718484075 = linksInTable.linksInTableDescriptionHeading._15_44_11718484075;
	}

    @Override
    public void remove() {
        super.remove();
	    if (linksInTable != null) linksInTable.unregister();
	}

	public class LinksInTable extends io.intino.alexandria.ui.displays.components.Table<B, io.intino.alexandria.ui.displays.components.Row, org.monet.space.kernel.model.Node>  {
		public NodeLinksInTemplate.LinksInTable. LinksInTableLabelHeading linksInTableLabelHeading;
		public NodeLinksInTemplate.LinksInTable. LinksInTableDescriptionHeading linksInTableDescriptionHeading;

		public LinksInTable(B box) {
			super(box);

			_pageSize(20);
		}

		@Override
		public void init() {
			super.init();
			if (linksInTableLabelHeading == null) linksInTableLabelHeading = register(new LinksInTableLabelHeading(box()).<LinksInTableLabelHeading>id("a_1289219689").owner(AbstractNodeLinksInTemplate.this));
			if (linksInTableDescriptionHeading == null) linksInTableDescriptionHeading = register(new LinksInTableDescriptionHeading(box()).<LinksInTableDescriptionHeading>id("a1141824812").owner(AbstractNodeLinksInTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (linksInTableLabelHeading != null) linksInTableLabelHeading.unregister();
			if (linksInTableDescriptionHeading != null) linksInTableDescriptionHeading.unregister();
		}


		public LinksInTableRow create(org.monet.space.kernel.model.Node item) {
			LinksInTableRow row = new LinksInTableRow((UnitBox)box());
			row.id(java.util.UUID.randomUUID().toString());
			row.item(item);
			return row;
		}
		public class LinksInTableLabelHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public NodeLinksInTemplate.LinksInTable.LinksInTableLabelHeading. _12_38_11182118849 _12_38_11182118849;

			public LinksInTableLabelHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_12_38_11182118849 == null) _12_38_11182118849 = register(new _12_38_11182118849(box()).<_12_38_11182118849>id("a1974135901").owner(AbstractNodeLinksInTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_12_38_11182118849 != null) _12_38_11182118849.unregister();
			}

			public class _12_38_11182118849 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _12_38_11182118849(B box) {
					super(box);
					_value("Título");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}

		public class LinksInTableDescriptionHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public NodeLinksInTemplate.LinksInTable.LinksInTableDescriptionHeading. _15_44_11718484075 _15_44_11718484075;

			public LinksInTableDescriptionHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_15_44_11718484075 == null) _15_44_11718484075 = register(new _15_44_11718484075(box()).<_15_44_11718484075>id("a1460818572").owner(AbstractNodeLinksInTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_15_44_11718484075 != null) _15_44_11718484075.unregister();
			}

			public class _15_44_11718484075 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _15_44_11718484075(B box) {
					super(box);
					_value("Descripción");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}
	}
}
